@@ -164,10 +164,14 @@ class ALog(object):
                 write_repr = 'OBJECT IS NULL'
         except TypeError:
             write_repr = 'OBJECT CAN`T NOT PARSE'
+        # 时间
         t = datetime.datetime.utcnow().strftime('%Y-%m-%d %H:%M:%S.%f')
+        # 只输出文本
         pure_text = ' '.join([str(t), str(field.value), str(line), str(hex(id(obj))),
                               '[{}]'.format(task_name), str(write_repr), f" : {msg}"])
+
         t = ConsoleWrite.format_color(f"{t}".ljust(FieldsLength.DATETIME_FORMAT), ConsoleColor.FontColor.CYAN)
+        # 执行类型
         _field = ConsoleWrite.format_color(f"{field.value}".rjust(FieldsLength.INFO_FORMAT),
                                            ConsoleColor.FontColor.GREEN
                                            if field == LogStatus.Info
@@ -176,15 +180,21 @@ class ALog(object):
                                            else ConsoleColor.FontColor.YELLOW
                                            if field == LogStatus.Warn
                                            else ConsoleColor.FontColor.YELLOW)
+        # 所在行数
         line = f"{line}".rjust(FieldsLength.LINE_FORMAT)
-        hex_id = ConsoleWrite.format_color(f" {str(hex(id(obj)))}", ConsoleColor.FontColor.PINK)
+        # 执行的类ID
+        hex_id = ConsoleWrite.format_color(f" {str(hex(id(obj))).upper()}", ConsoleColor.FontColor.PINK)
+        # 执行类型名称
         task_name = ConsoleWrite.format_color(f"{task_name}".rjust(FieldsLength.TASK_FORMAT),
                                               ConsoleColor.FontColor.PURPLE)
+        # 类
         write_repr = ConsoleWrite.format_color(write_repr,
                                                ConsoleColor.FontColor.LIGHT_GREEN
                                                if field != LogStatus.Error
                                                else ConsoleColor.FontColor.RED)
+        # 格式化消息颜色
         msg = ConsoleWrite.format_color(f" : {msg}", text_color)
+        # 组合消息
         info = "{}{}{}{}{}{}{}".format(t, _field, line, hex_id, ' [{}] '.format(task_name), write_repr, msg)
         if ned_text:
             return info, pure_text
@@ -369,4 +379,14 @@ class logging(object):
 
     @classmethod
     def gen(cls, _object) -> ALog:
+        """
+        使用实例化后的对象获取log日志对象
+        """
         return _object.log_obj
+
+    @classmethod
+    def gen_cls(cls, _class) -> ALog:
+        """
+        使用类获取log日志对象
+        """
+        return _class().log_obj
