@@ -1,3 +1,5 @@
+import re
+
 from .AopContainer import AopModelObject
 from .Modes import EX_MODEL
 from .Serialize import QuerySet
@@ -68,7 +70,7 @@ def Select(sql: str):
 
 
 def SelectAbst():
-    def mysql_rp(n, array) -> str:
+    def mysql_rp(n, array, obj) -> str:
         _name = array[len(array) - 1] if len(array) > 0 else ""
         rule = {
             'F': 'FROM',
@@ -81,7 +83,7 @@ def SelectAbst():
             'ge': '>= #{%s}' % _name,
             'in': 'in #{%s}' % _name,
             'like': 'like #{%s}' % _name,
-            'all': '*',
+            'all': ','.join([obj.orm.ParseUtil.parse_key(f) for f in obj.fields]),
         }
         return rule[n] if n in rule.keys() else n
 
@@ -94,7 +96,7 @@ def SelectAbst():
             _name = func.__name__.split("_")
             S = []
             for i in _name:
-                d = mysql_rp(i, S)
+                d = mysql_rp(i, S, obj)
                 S.append(d if d != "FROM" else f"FROM {obj.__table_name__}")
 
             sql = ' '.join(S)
@@ -225,10 +227,9 @@ def ReadXml(filename):
     """读取xml"""
 
     def set_to_field(cls):
-        sep = os.sep
-
         file_path = inspect.getfile(cls)
-        file_path = file_path[:file_path.rfind(sep)]
+        # 分割字符串得到当前路径
+        file_path = '/'.join(re.split(r'[/|\\]', file_path)[:-1])
         path = os.path.join(file_path, filename)
 
         setattr(cls, '_xml_file', path)
@@ -243,6 +244,8 @@ def ReadXml(filename):
 def Item(_id, d=False):
     """
     将xml的item节点映射到当前方法,对应的id字段为xml节点的id
+    :param _id: 节点id
+    :param d: 查询时返回原始数据
     """
 
     def replaceNextLine(sql):
@@ -260,7 +263,13 @@ def Item(_id, d=False):
             xml = obj.xNode
 
             xml_node = None
-            for v in xml.children['item']:
+            # 增删改查的节点加起来得到所有操作节点
+            node_list = xml.children['select'] \
+                        + xml.children['insert'] \
+                        + xml.children['update'] \
+                        + xml.children['delete']
+            # 从所有的可操作节点中寻找id符合的节点
+            for v in node_list:
                 if 'id' in v.attrs.keys() and v.attrs['id'].text == _id:
                     xml_node = v
                     break
@@ -281,15 +290,20 @@ def Item(_id, d=False):
             run_sql = replaceNextLine(result_text_node.text)
             sub_sql, params = TextUtil.replace_antlr(run_sql, **kwargs)
             # 返回值ast
-            if 'resultType' in result_text_node.mark.keys():
+            if xml_node.node.tagName.lower() == 'select':
                 result = obj.execute_sql(sql=sub_sql, params=params, mode=EX_MODEL.SELECT, **obj.__dict__)
+                # 将返回的结果解析
                 resultTree = ResultMapNode(obj, result_text_node, result)
                 if d:
                     return result
-                return resultTree.apply()
+                return resultTree.apply(xml.children['resultMap'])
             else:
+                # 是否需要返回最后一行id，默认返回
+                has_last_id = bool(result_text_node.expand_data['last']) \
+                    if 'last' in result_text_node.expand_data.keys() else True
+
                 result = obj.execute_sql(sql=sub_sql, params=params, mode=EX_MODEL.UPDATE,
-                                         **{'last_id': result_text_node.mark['has_last_id'], **obj.__dict__})
+                                         **{'last_id': has_last_id, **obj.__dict__})
                 return result
 
         return _wrapper_
