@@ -1,3 +1,4 @@
+import re
 from enum import Enum
 from typing import List
 
@@ -104,7 +105,7 @@ s        """
         self.__table_name__ = repository.__table_name__
 
         self.first_data = False
-        self._result = []
+        self.result = []
 
     def top(self):
         self.find()
@@ -128,6 +129,7 @@ s        """
         Attributes:
             asses:将对应的字段转成另一个别名,不需要转换的使用None标识
             h_func:不将字段转换成 `%s` 格式
+            poly:是否要在末尾加上[from table_name]，常用于使用加号连表时
         更新:
             如果args字段长度为0,默认为查找全部
         """
@@ -224,6 +226,9 @@ s        """
     def filter(self, **kwargs):
         return self.find().where(**kwargs).end()
 
+    async def filter_async(self, **kwargs):
+        return self.filter(**kwargs)
+
     def where(self, **kwargs):
         """
         当....
@@ -248,10 +253,12 @@ s        """
             sym = '='
 
             sps = cp_key.split('__')
-
-            if len(str(value)) > 2 and str(value)[0:2] in self.sqlFields.symbol:
-                sym = value[0:2]
-                value = str(value)[2:len(str(value))]
+            rpx_symbol = re.findall(r"([%s]{2})(.*)" % ','.join(self.sqlFields.symbol), str(value))
+            # UPDATE [1.0.6a2] 使用正则方式替换,减少误判情况造成无法使用特殊运算符拼接sql
+            # if len(str(value)) > 2 and str(value)[0:2] in self.sqlFields.symbol:
+            if len(rpx_symbol) > 0:
+                params = rpx_symbol[0]
+                sym, value = params[0], params[1]
                 if sym == '==':
                     sym = '='
                 elif sym == '>>':
@@ -272,8 +279,7 @@ s        """
             elif not len(sps) == 1:
                 customize = True
                 sym = sps[len(sps) - 1]
-                self.ParseUtil.fieldExist(
-                    self.ParseUtil, 'adapter', raise_exception=True)
+                self.ParseUtil.fieldExist(self.ParseUtil, 'adapter', raise_exception=True)
                 cp_key = cp_key[:cp_key.rfind('__' + sym)]
                 self.ParseUtil.adapter.funcs[sym](self, cp_key, value)
 
@@ -370,7 +376,7 @@ s        """
         self.args.append(self.sqlFields.ander_str)
         return self
 
-    def run(self, need_sql=False, serializer=True) -> QuerySet:
+    def __run__(self, need_sql=False, serializer=True) -> QuerySet:
         """
         最终执行任务
         """
@@ -382,7 +388,7 @@ s        """
         if need_sql:
             return sql
         if self.exmode == AOrm.Mode.FIND:
-            self._result = self.repository.db_util.select(
+            self.result = self.repository.db_util.select(
                 sql=sql,
                 params=self.params,
                 print_sql=print_sql,
@@ -390,13 +396,14 @@ s        """
                 **self.repository.__dict__
             )
             _result_objs = []
-            for i in self._result:
-                _obj = self.ParseUtil.parse_obj(
-                    data=i, instance=self.repository.instance)
-                _result_objs.append(_obj)
-            self._result = _result_objs
+            if self.result is not None:
+                for i in self.result:
+                    _obj = self.ParseUtil.parse_obj(
+                        data=i, instance=self.repository.instance)
+                    _result_objs.append(_obj)
+            self.result = _result_objs
         else:
-            self._result = self.repository.db_util.update(
+            self.result = self.repository.db_util.update(
                 sql=sql,
                 params=self.params,
                 print_sql=print_sql,
@@ -406,21 +413,21 @@ s        """
         self.args.clear()
         self.params.clear()
         if self.first_data:
-            if (isinstance(self._result, list) or isinstance(self._result, tuple)) and self._result and len(
-                    self._result) > 0:
+            if (isinstance(self.result, list) or isinstance(self.result, tuple)) and self.result and len(
+                    self.result) > 0:
                 if not serializer:
-                    return self._result[0]
+                    return self.result[0]
                 self.repository.result = self.serializer(instance=self.repository.instance,
-                                                         base_data=self._result).first()
+                                                         base_data=self.result).first()
                 return self.repository.result
             else:
                 self.repository.result = self.serializer()
                 return self.repository.result
         else:
             if not serializer:
-                return self._result
+                return self.result
             self.repository.result = self.serializer(
-                instance=self.repository.instance, base_data=self._result)
+                instance=self.repository.instance, base_data=self.result)
             return self.repository.result
 
     def con_from(self):
@@ -450,7 +457,10 @@ s        """
         return self
 
     def end(self, **kwargs):
-        return self.run(**kwargs)
+        return self.__run__(**kwargs)
+
+    async def end_async(self, **kwargs):
+        return self.__run__(**kwargs)
 
     def __rshift__(self, other):
         """
@@ -498,5 +508,5 @@ s        """
         """
         return self.repository.config_obj.opera(self.repository).check()
 
-    def create(self):
-        return self.repository.config_obj.opera(self.repository).create()
+    def create(self, replace=False):
+        return self.repository.config_obj.opera(self.repository).create(replace)
